/*****************************************************************************
 Copyright (c) 1993 UUNET Technologies
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.
 3. All advertising materials mentioning features or use of this software
    must display the following acknowledgement:
      This product includes software developed by UUNET Technologies
 4. The name UUNET Technologies may not be used to endorse or promote products  
    derived from this software without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE UUNET Technologies ``AS IS'' AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 ARE DISCLAIMED.  IN NO EVENT SHALL THE UUNET Technologies BE LIABLE
 FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

*****************************************************************************/

#include <sfio.h>
#include <general.h>

#define PROTO_LIST(list) list
#define POINTER void*

#include <rsaref.h>
#include <r_encode.h>

#include <misc.h>

void RSAerr(int code)
{
  char *expl;
  
  switch(code) {
	case RE_CONTENT_ENCODING:
    expl = "(Encrypted) content has RFC 1113 encoding error";
    break;
  case RE_DIGEST_ALGORITHM:
    expl = "Message-digest algorithm is invalid";
    break;
	case RE_KEY:
    expl = "Recovered DES key cannot decrypt encrypted content or encrypt signature";
    break;
  case RE_KEY_ENCODING:
    expl = "Encrypted key has RFC 1113 encoding error";
    break;
  case RE_MODULUS_LEN:
    expl = "Modulus length is invalid";
    break;
  case RE_NEED_RANDOM:
    expl = "Random structure is not seeded";
    break;
  case RE_PRIVATE_KEY:
    expl = "Private key cannot encrypt message digest, or cannot decrypt encrypted key";
    break;
  case RE_PUBLIC_KEY:
    expl = "Public key cannot encrypt DES key, or cannot decrypt signature";
    break;
  case RE_SIGNATURE:
    expl = "Signature on content or block is incorrect";
    break;
  case RE_SIGNATURE_ENCODING:
    expl = "(Encrypted) signature has RFC 1113 encoding error";
    break;
    
  default:
    expl = "??";
  }
  
  sfprintf(sferr, "RSA error 0x%04x, %s\n", code, expl);
}
